@@ -10,6 +10,13 @@ use utils::parse;
 
 const EXCHANGE_NAME: &str = "bitfinex";
 
+#[test_case(MarketType::Spot)]
+#[test_case(MarketType::LinearSwap)]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
+async fn test_crawl_trade_all(market_type: MarketType) {
+    test_all_symbols!(crawl_trade, EXCHANGE_NAME, market_type, MessageType::Trade)
+}
+
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 #[tokio::test(flavor = "multi_thread")]
@@ -112,7 +119,7 @@ async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 
 #[test_case(MarketType::Spot)]
 #[test_case(MarketType::LinearSwap)]
-#[tokio::test(flavor = "multi_thread")]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
 async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
